@@ -1,6 +1,6 @@
 ﻿#
 # The MIT License (MIT)
-# Copyright (c) 2021 M.O.S.S. Computer Grafik Systeme GmbH
+# Copyright (c) 2022 M.O.S.S. Computer Grafik Systeme GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the "Software"),
@@ -20,11 +20,12 @@
 # OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-import sys
-import os
-from os import walk, listdir
-from os.path import isdir, isfile, join, exists
 import logging
+import os
+import sys
+from os import listdir, walk
+from os.path import exists, isdir, isfile, join
+
 from tqdm import tqdm
 
 logger = logging.getLogger("ems_cli_import")
@@ -53,7 +54,8 @@ class EmsCliImport:
 
         logger.info("Starting import process")
         logger.debug(
-            "Projects in the current instance: %s", self.ems_service.projects,  # type: ignore
+            "Projects in the current instance: %s",
+            self.ems_service.projects,  # type: ignore
         )
 
         # Check if the path exist
@@ -104,7 +106,8 @@ class EmsCliImport:
         # Looking for the VNT Master Objectclass
         variant_master_found = None
         logger.info(
-            "Looking for a VARIANTMASTER in the project structure ... i.e. a variant project"
+            "Looking for a VARIANTMASTER in the project structure ... i.e. a variant"
+            " project"
         )
         variant_master_found = next(
             (item for item in objectclasses if item.objectClassType == "VNTMASTER"),
@@ -213,7 +216,8 @@ class EmsCliImport:
                     if "code" in result_dict:
                         error_dict = result_dict
                         raise EmsCliException(
-                            "Could not add master variant features:\n\tCode: {}\n\tMessage: {}\n\tDescription: {}".format(
+                            "Could not add master variant features:\n\tCode:"
+                            " {}\n\tMessage: {}\n\tDescription: {}".format(
                                 error_dict["code"],
                                 error_dict["message"],
                                 error_dict["description"],
@@ -222,7 +226,8 @@ class EmsCliImport:
                     if "error" in result_dict["addResults"][0]:
                         error_dict = result_dict["addResults"][0]["error"]
                         raise EmsCliException(
-                            "Could not add master variant features:\n\tCode: {}\n\tMessage: {}\n\tDescription: {}".format(
+                            "Could not add master variant features:\n\tCode:"
+                            " {}\n\tMessage: {}\n\tDescription: {}".format(
                                 error_dict["code"],
                                 error_dict["message"],
                                 error_dict["description"],
@@ -244,7 +249,8 @@ class EmsCliImport:
                         )
                     # read the variants for the master feature
                     logger.info(
-                        "Reading the variants for the master features in 'variants.json'"
+                        "Reading the variants for the master features in"
+                        " 'variants.json'"
                     )
                     exported_variants = self.file2json(  # type: ignore
                         join(master_variant_dir, "variants.json")
